package com.ruoyi.web.controller.system;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.redis.enums.RedisCacheKey;
import com.ruoyi.common.enums.UserStatus;
import com.ruoyi.common.enums.UserType;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.SmBalancePeriod;
import com.ruoyi.system.domain.SmBusinessRecord;
import com.ruoyi.system.domain.dto.*;
import com.ruoyi.system.domain.enums.device.DeviceOnlineStatus;
import com.ruoyi.system.domain.enums.transactionBill.TransactionBillGroupBy;
import com.ruoyi.system.domain.enums.transactionBill.TransactionBillStatus;
import com.ruoyi.system.domain.vo.SmBusinessRecordVo;
import com.ruoyi.system.domain.vo.dashboard.BillCountVo;
import com.ruoyi.system.domain.vo.dashboard.BriefVo;
import com.ruoyi.system.service.*;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * 报表Controller
 * @author 辉
 * 2024/3/6
 */
@RestController
@RequestMapping("/system/dashboard")
public class SmDashboardController {


    @Autowired
    private ISmTransactionBillService transactionBillService;

    @Autowired
    private ISmBalancePeriodService balancePeriodService;

    @Autowired
    private ISmBusinessRecordService businessRecordService;

    @Autowired
    private RedisCache redisCache;

    /**
     * 舆情分析数据
     */
    @GetMapping("/brief")
    public AjaxResult brief() {
        BriefVo brief = businessRecordService.selectBrief();

        Date today = new Date();
        Date startDate = DateUtils.plusDate(today, -12);
        Date endDate = DateUtils.plusDate(today, -1);
        List<SmBusinessRecordVo> history = businessRecordService.selectDailyLatest(startDate, endDate);

        brief.setHistory(history);

        return AjaxResult.success(brief);
    }

    /**
     * 获取账单分时统计数据
     * @param dto 查询条件
     * @return 统计数据
     */
    @GetMapping("/hourBillCount")
    public AjaxResult hourBillCount(@Validated(ValidGroup.Query.class) SmTransactionBillDto dto) {
        dto.setGroupBy(TransactionBillGroupBy.create_hour.name());
        dto.setStatus(TransactionBillStatus.SUCCESS.getStatus());
        return AjaxResult.success(transactionBillService.selectCount(dto));
    }

    /**
     * 获取余额时段分析
     */
    @ApiOperation("获取余额时段分析")
    @GetMapping("/balancePeriod")
    public AjaxResult balancePeriod(SmBalancePeriodDto dto) {
        return AjaxResult.success(balancePeriodService.selectSmBalancePeriodList(dto));
    }
}
