package com.ruoyi.system.service.impl;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.system.domain.SmTransactionBill;
import com.ruoyi.system.domain.dto.SmBalancePeriodDto;
import com.ruoyi.system.domain.dto.SmTransactionBillDto;
import com.ruoyi.system.domain.dto.SmUserDto;
import com.ruoyi.system.domain.enums.transactionBill.TransactionBillGroupBy;
import com.ruoyi.system.domain.enums.transactionBill.TransactionBillStatus;
import com.ruoyi.system.domain.vo.dashboard.BillCountVo;
import com.ruoyi.system.mapper.SmTransactionBillMapper;
import com.ruoyi.system.mapper.SmUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SmBalancePeriodMapper;
import com.ruoyi.system.domain.SmBalancePeriod;
import com.ruoyi.system.service.ISmBalancePeriodService;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

/**
 * 余额时段记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-03-16
 */
@Service("smBalancePeriodService")
public class SmBalancePeriodServiceImpl implements ISmBalancePeriodService 
{
    @Autowired
    private SmBalancePeriodMapper smBalancePeriodMapper;

    @Autowired
    private SmUserMapper smUserMapper;

    @Autowired
    private SmTransactionBillMapper smTransactionBillMapper;

    /**
     * 查询余额时段记录
     * 
     * @param id 余额时段记录主键
     * @return 余额时段记录
     */
    @Override
    public SmBalancePeriod selectSmBalancePeriodById(Long id)
    {
        return smBalancePeriodMapper.selectSmBalancePeriodById(id);
    }

    /**
     * 查询余额时段记录列表
     * 
     * @param smBalancePeriod 余额时段记录
     * @return 余额时段记录
     */
    @Override
    public List<SmBalancePeriod> selectSmBalancePeriodList(SmBalancePeriodDto smBalancePeriod)
    {
        return smBalancePeriodMapper.selectSmBalancePeriodList(smBalancePeriod);
    }

    /**
     * 新增余额时段记录
     * 
     * @param smBalancePeriod 余额时段记录
     * @return 结果
     */
    @Override
    public int insertSmBalancePeriod(SmBalancePeriod smBalancePeriod)
    {
        smBalancePeriod.setCreateTime(DateUtils.getNowDate());
        return smBalancePeriodMapper.insertSmBalancePeriod(smBalancePeriod);
    }

    /**
     * 修改余额时段记录
     * 
     * @param smBalancePeriod 余额时段记录
     * @return 结果
     */
    @Override
    public int updateSmBalancePeriod(SmBalancePeriod smBalancePeriod)
    {
        return smBalancePeriodMapper.updateSmBalancePeriod(smBalancePeriod);
    }

    /**
     * 批量删除余额时段记录
     * 
     * @param ids 需要删除的余额时段记录主键
     * @return 结果
     */
    @Override
    public int deleteSmBalancePeriodByIds(Long[] ids)
    {
        return smBalancePeriodMapper.deleteSmBalancePeriodByIds(ids);
    }

    /**
     * 删除余额时段记录信息
     * 
     * @param id 余额时段记录主键
     * @return 结果
     */
    @Override
    public int deleteSmBalancePeriodById(Long id)
    {
        return smBalancePeriodMapper.deleteSmBalancePeriodById(id);
    }



    @Override
    @Transactional
    public void recordCurrentBalance() {
        Date now = new Date();
        SmBalancePeriod data = new SmBalancePeriod();

        // 用户总余额
        data.setUserBalance(smUserMapper.selectBalanceCount(new SmUserDto()));

        // 平台总余额
        List<BillCountVo> platFormBillCount = smTransactionBillMapper.selectCount(new SmTransactionBillDto());
        data.setPlatformBalance(CollectionUtils.isEmpty(platFormBillCount) ? BigDecimal.ZERO : platFormBillCount.get(0).getServiceCharge());

        // 充值
        SmTransactionBillDto dto = new SmTransactionBillDto();
        dto.setCreateDate(now);
        dto.setHour(now.getHours());
        dto.setGroupBy(TransactionBillGroupBy.create_hour.name());
        dto.setStatus(TransactionBillStatus.SUCCESS.getStatus());
        List<BillCountVo> billCount = smTransactionBillMapper.selectCount(dto);
        data.setRecharge(CollectionUtils.isEmpty(billCount) ? BigDecimal.ZERO : billCount.get(0).getRecharge());

        data.setCreateTime(now);
        smBalancePeriodMapper.insertSmBalancePeriod(data);
    }

    @Override
    public boolean isExist(Date date, Integer hour) {
        SmBalancePeriodDto balanceDto = new SmBalancePeriodDto();
        balanceDto.setCreateDate(date);
        balanceDto.setCreateHour(hour);
        List<SmBalancePeriod> smBalancePeriods = smBalancePeriodMapper.selectSmBalancePeriodList(balanceDto);
        return !CollectionUtils.isEmpty(smBalancePeriods);
    }
}
