package com.ruoyi.system.task.bill;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.SmTransactionBill;
import com.ruoyi.system.domain.dto.SmTransactionBillDto;
import com.ruoyi.system.domain.enums.transactionBill.TransactionBillStatus;
import com.ruoyi.system.domain.enums.transactionBill.TransactionBillType;
import com.ruoyi.system.domain.vo.SmTransactionBillVo;
import com.ruoyi.system.service.ISmTransactionBillService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/4/10
 */
@Component("payTask")
@Slf4j
public class PayTask {

    @Autowired
    private ISmTransactionBillService transactionBillService;

    /**
     * 更新支付结果
     */
    @Transactional
    public void refreshPayResult() {
        // 查询十分钟以内支付中的充值订单
        Date now = new Date();
        Date past = DateUtils.addMinutes(now, -10);
        SmTransactionBillDto dto = new SmTransactionBillDto();
        dto.setStartDate(past);
        dto.setType(TransactionBillType.RECHARGE.getType());
        dto.setStatus(TransactionBillStatus.PAYING.getStatus());
        List<SmTransactionBillVo> billList = transactionBillService.selectSmTransactionBillList(dto);
        if (CollectionUtils.isEmpty(billList)) {
            log.info("十分钟以内没有支付中的订单");
            return;
        }

        transactionBillService.refreshPayResult(billList.stream().map(SmTransactionBill::getBillId).collect(Collectors.toList()));
    }

}
